wsireg.utils package
====================

Submodules
----------

wsireg.utils.config\_utils module
---------------------------------

.. automodule:: wsireg.utils.config_utils
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.utils.im\_utils module
-----------------------------

.. automodule:: wsireg.utils.im_utils
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.utils.itk\_im\_conversions module
----------------------------------------

.. automodule:: wsireg.utils.itk_im_conversions
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.utils.reg\_utils module
------------------------------

.. automodule:: wsireg.utils.reg_utils
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.utils.shape\_utils module
--------------------------------

.. automodule:: wsireg.utils.shape_utils
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.utils.tform\_conversion module
-------------------------------------

.. automodule:: wsireg.utils.tform_conversion
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.utils.tform\_utils module
--------------------------------

.. automodule:: wsireg.utils.tform_utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: wsireg.utils
   :members:
   :undoc-members:
   :show-inheritance:
